import React, { useState, useEffect, useRef } from 'react'
import withLayout from '@/layout'
import { ScrollView, Image } from '@tarojs/components'
import { getChannelRank } from '@/services/agent'
import { fetch } from '@/utils/request'
import { API_GET_AGENT_BUILDINGS } from '@/constants/api'
import {  } from '@/constants/user'
import DateRangePicker from '@/components/DateRangePicker'
import Picker from '@/components/Picker'
import LineChat from './components/LineChat'
// import '@/assets/css/iconfont.css'
import './index.scss'

const lineXDicts = [
  {name: '按天', id: 'day'},
  {name: '按月', id: 'month'},
]

const padMonth = m => m > 9 ? m : `0${m}`

export default withLayout((props) => {
  
  const [showPicker, setShowPicker] = useState(false)
  const [rankDateRange, setRankDateRange] = useState([])
  const [reportDateRange, setReportDateRange] = useState([])
  const [buildingId, setBuildingId] = useState()
  const [buildingList, setBuildingList] = useState([])
  const [rankList, setRankList] = useState([])
  const [lineXType, setLineXType] = useState('day')
  const [lingeDateRange, seteLineDateRange] = useState([])
  const pickerTrigger = useRef()

  const handleRankDate = () => {
    pickerTrigger.current = 'rank'
    setShowPicker(true)
  }

  const handleReportDate = () => {
    pickerTrigger.current = 'report'
    setShowPicker(true)
  }
  
  const handlePickerChange = (e) => {
    setShowPicker(false)

    if (pickerTrigger.current == 'rank') {
      setRankDateRange(e)
    } else {
      setReportDateRange(e)
    }
  }

  useEffect(() => {
    fetch({ url: API_GET_AGENT_BUILDINGS }).then((res) => {
      const buildings = res || []
      setBuildingList(buildings)
      if (buildings.length) {
        setBuildingId(buildings[0].buildingId)
      }
    })
  }, [])

  useEffect(() => {
    if (buildingId) {
      getChannelRank({buildingId}).then((res) => {
        setRankList(res || [])
      })
    }
  }, [buildingId])

  useEffect(() => {
    const now = new Date()
    const endDay = now.toJSON().substring(0, 10)
    if (lineXType === 'day') {
      const cutDay = 7 * 24 * 60 * 60 * 1000
      const start = new Date(now - cutDay)
      seteLineDateRange([start.toJSON().substring(0, 10), endDay])
    } else {
      const cutMonth = 6
      const curMonth = now.getMonth() + 1
      const startMonth = curMonth - cutMonth + 1
      if (startMonth <= 0) {
        const startYear = now.getFullYear() - 1
        seteLineDateRange([`${startYear}-${padMonth(startMonth + 12)}-01`, endDay])
      } else {
        seteLineDateRange([`${now.getFullYear()}-${padMonth(startMonth)}-01`, endDay])
      }
    }
    
  }, [lineXType])

  return (
    <view className='Page partnerChannel'>
      <DateRangePicker visable={showPicker} close={() => setShowPicker(false)} change={handlePickerChange} />
      <ScrollView scrollY>
        <view className='PageContent'>

          {/* 排行榜 */}
          <view className='Ranking'>
            <view className='Top flex-h'>
              <text className='flex-item'>龙虎榜</text>
              <Image mode='heightFix' src={require('@/assets/mine-icon23.png')} onClick={handleRankDate} />
            </view>
            <view className='List flex-h'>
              {
                rankList.map((item, index) => (
                  <view className={index === 1 ? 'flex-item active' : 'flex-item'} key={`ListItem-${index}`}>
                    {
                      index === 0 &&
                      <Image mode='heightFix' src={require('@/assets/mine-icon21.png')}></Image>
                    }
                    {
                      index === 1 &&
                      <Image mode='heightFix' src={require('@/assets/mine-icon20.png')}></Image>
                    }
                    {
                      index === 2 &&
                      <Image mode='heightFix' src={require('@/assets/mine-icon22.png')}></Image>
                    }
                    <view className='Icon'>
                      <Image mode='aspectFill' src={item.avatarurl || null}></Image>
                    </view>
                    <view className='Index'>
                      <text>{item.name}</text>
                      <text>{index === 0 ? 2 : index === 1 ? 1 : 3}</text>
                    </view>
                    <view className='Num'>
                      <text></text>
                      <text>{item.number}</text>
                    </view>
                  </view>
                ))
              }
            </view>
          </view>

          {/* 销售简报 */}
          <view className='SaleNews'>
            <view className='Top flex-h'>
              <text>销售简报</text>
              <Image mode='heightFix' src={require('../../../assets/mine-icon23.png')} onClick={handleReportDate}></Image>
              <view className='flex-item'></view>
              <text>更多</text>
              <text className='iconfont icon-jiantouright'></text>
            </view>
            <view className='List'>
              <view className='flex-h'>
                <text className='flex-item'>新增客户</text>
                <text>34人</text>
                <text className='iconfont icon-jiantouright'></text>
              </view>
              <view className='flex-h'>
                <text className='flex-item'>跟进客户</text>
                <text>34人</text>
                <text className='iconfont icon-jiantouright'></text>
              </view>
              <view className='flex-h'>
                <text className='flex-item'>成交客户</text>
                <text>34人</text>
                <text className='iconfont icon-jiantouright'></text>
              </view>
            </view>
          </view>

          {/* 销售趋势 */}
          <view className='SaleLineChart'>
            <view className='Top flex-h'>
              <text>销售趋势</text>
              <view className='flex-item'></view>
              <view className='Type'>
                <text>新增客户</text>
                <text className='iconfont icon-sanjiaoxingdown'></text>
              </view>
              <view className='Sort'>
                <Picker kv={['name', 'id']} dicts={lineXDicts} value={lineXType} onChange={setLineXType} />
                <text className='iconfont icon-sanjiaoxingdown'></text>
              </view>
            </view>
            <view className='LineChart'>
              <LineChat buildingId={buildingId} xType={lineXType} dateRange={lingeDateRange} />
            </view>
          </view>

        </view>
      </ScrollView>
    </view>
  )
})
